@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -20,8 +22,9 @@
 Template tags for customizing Horizon.
 """
 
-from django.conf import settings
 from django import template
+from django.conf import settings
+from django.utils.translation import ugettext as _
 
 
 register = template.Library()
@@ -29,7 +32,7 @@ register = template.Library()
 
 class SiteBrandingNode(template.Node):
     def render(self, context):
-        return settings.SITE_BRANDING
+        return getattr(settings, "SITE_BRANDING", _("Horizon"))
 
 
 @register.tag
@@ -42,14 +45,9 @@ def site_title(parser, token):
     return settings.SITE_BRANDING
 
 
-@register.simple_tag
-def site_branding_link():
-    return settings.SITE_BRANDING_LINK
-
-
 # TODO(jeffjapan): This is just an assignment tag version of the above, replace
 #                  when the dashboard is upgraded to a django version that
-#                  supports the @simple_tag decorator syntax instead.
+#                  supports the @assignment_tag decorator syntax instead.
 class SaveBrandingNode(template.Node):
     def __init__(self, var_name):
         self.var_name = var_name
