@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 Nebula, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -12,24 +14,24 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
-from openstack_auth import utils
 
 import horizon
 
 
+class SystemPanels(horizon.PanelGroup):
+    slug = "admin"
+    name = _("System Panel")
+    panels = ('overview', 'instances', 'volumes', 'flavors',
+              'images', 'projects', 'users', 'networks', 'routers', 'info')
+
+
 class Admin(horizon.Dashboard):
     name = _("Admin")
     slug = "admin"
+    panels = (SystemPanels,)
+    default_panel = 'overview'
+    permissions = ('openstack.roles.admin',)
 
-    if getattr(settings, 'POLICY_CHECK_FUNCTION', None):
-        policy_rules = (('identity', 'admin_required'),
-                        ('image', 'context_is_admin'),
-                        ('volume', 'context_is_admin'),
-                        ('compute', 'context_is_admin'),
-                        ('network', 'context_is_admin'),)
-    else:
-        permissions = (tuple(utils.get_admin_permissions()),)
 
 horizon.register(Admin)
