@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -16,13 +18,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from openstack_dashboard.dashboards.project.images.images \
-    import forms as images_forms
+from openstack_dashboard.dashboards.project.images_and_snapshots \
+        .images import forms
 
 
-class AdminCreateImageForm(images_forms.CreateImageForm):
+class AdminCreateImageForm(forms.CreateImageForm):
     pass
 
 
-class AdminUpdateImageForm(images_forms.UpdateImageForm):
+class AdminUpdateImageForm(forms.UpdateImageForm):
     pass
