@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -16,21 +18,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf import settings
-from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ugettext_lazy as _
 
 import horizon
 
+from openstack_dashboard.dashboards.admin import dashboard
+
 
 class Images(horizon.Panel):
     name = _("Images")
     slug = 'images'
-    permissions = ('openstack.services.image',)
-    policy_rules = ((("image", "context_is_admin"),
-                     ("image", "get_images")),)
 
-    def allowed(self, context):
-        if (('compute' in settings.SYSTEM_SCOPE_SERVICES) !=
-                bool(context['request'].user.system_scoped)):
-            return False
-        return super().allowed(context)
+
+dashboard.Admin.register(Images)
