@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -16,11 +18,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.urls import re_path
+from django.conf.urls.defaults import patterns, url
 
-from openstack_dashboard.dashboards.admin.info import views
+from .views import IndexView
 
 
-urlpatterns = [
-    re_path(r'^$', views.IndexView.as_view(), name='index'),
-]
+urlpatterns = patterns('openstack_dashboard.dashboards.admin.info.views',
+    url(r'^$', IndexView.as_view(), name='index'))
