@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012,  Nachi Ueno,  NTT MCL,  Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -12,27 +14,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf import settings
-from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ugettext_lazy as _
 
 import horizon
 
-from openstack_dashboard.utils import settings as setting_utils
+from openstack_dashboard.dashboards.admin import dashboard
 
 
 class Routers(horizon.Panel):
-    name = _("Routers")
+    name = "Routers"
     slug = 'routers'
     permissions = ('openstack.services.network',)
-    policy_rules = (("network", "context_is_admin"),)
 
-    @staticmethod
-    def can_register():
-        return setting_utils.get_dict_config(
-            'OPENSTACK_NEUTRON_NETWORK', 'enable_router')
-
-    def allowed(self, context):
-        if (('network' in settings.SYSTEM_SCOPE_SERVICES) !=
-                bool(context['request'].user.system_scoped)):
-            return False
-        return super().allowed(context)
+dashboard.Admin.register(Routers)
