@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012,  Nachi Ueno,  NTT MCL,  Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -12,24 +14,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.urls import re_path
+from django.conf.urls.defaults import patterns, url
 
-from openstack_dashboard.dashboards.admin.routers import views
+from .views import (IndexView, DetailView)
 
 
-ROUTER_URL = r'^(?P<router_id>[^/]+)/%s'
-
-
-urlpatterns = [
-    re_path(r'^$', views.IndexView.as_view(), name='index'),
-    re_path(r'^create/$', views.CreateView.as_view(), name='create'),
-    re_path(ROUTER_URL % '$',
-            views.DetailView.as_view(),
-            name='detail'),
-    re_path(ROUTER_URL % 'update',
-            views.UpdateView.as_view(),
-            name='update'),
-    re_path(r'^(?P<l3_agent_id>[^/]+)/l3_agent_list',
-            views.L3AgentView.as_view(),
-            name='l3_agent_list'),
-]
+urlpatterns = patterns('horizon.dashboards.admin.routers.views',
+    url(r'^$', IndexView.as_view(), name='index'),
+    url(r'^(?P<router_id>[^/]+)/$',
+        DetailView.as_view(),
+        name='detail'),
+)
