@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -16,23 +18,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf.urls import patterns
-from django.conf.urls import url
+from django.conf.urls.defaults import patterns, url
 
-from openstack_dashboard.dashboards.project.access_and_security.\
-    security_groups import views
+from .views import CreateView, DetailView, AddRuleView
 
 
-urlpatterns = patterns(
-    '',
-    url(r'^create/$', views.CreateView.as_view(), name='create'),
+urlpatterns = patterns('',
+    url(r'^create/$', CreateView.as_view(), name='create'),
     url(r'^(?P<security_group_id>[^/]+)/$',
-        views.DetailView.as_view(),
+        DetailView.as_view(),
         name='detail'),
     url(r'^(?P<security_group_id>[^/]+)/add_rule/$',
-        views.AddRuleView.as_view(),
-        name='add_rule'),
-    url(r'^(?P<security_group_id>[^/]+)/update/$',
-        views.UpdateView.as_view(),
-        name='update')
+        AddRuleView.as_view(),
+        name='add_rule')
 )
