@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012,  Nachi Ueno,  NTT MCL,  Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -11,14 +13,17 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+import logging
 
-from django.urls import reverse
-from django.utils.translation import gettext_lazy as _
+from django.core.urlresolvers import reverse
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon import tabs
 from openstack_dashboard import api
 
+LOG = logging.getLogger(__name__)
+
 
 class OverviewTab(tabs.Tab):
     name = _("Overview")
@@ -29,8 +34,8 @@ class OverviewTab(tabs.Tab):
     def get_context_data(self, request):
         port_id = self.tab_group.kwargs['port_id']
         try:
-            port = api.neutron.port_get(self.request, port_id)
-        except Exception:
+            port = api.quantum.port_get(self.request, port_id)
+        except:
             redirect = reverse(self.failure_url)
             msg = _('Unable to retrieve port details.')
             exceptions.handle(request, msg, redirect=redirect)
