@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 Nebula, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -12,11 +14,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.urls import re_path
+from django.conf.urls.defaults import patterns, url
 
-from openstack_dashboard.dashboards.settings.user import views
+from .views import UserSettingsView
 
 
-urlpatterns = [
-    re_path(r'^$', views.UserSettingsView.as_view(), name='index'),
-]
+urlpatterns = patterns('',
+    url(r'^$', UserSettingsView.as_view(), name='index'))
