@@ -21,9 +21,13 @@
 import logging
 import os
 import sys
+import warnings
 
 from openstack_dashboard import exceptions
 
+warnings.formatwarning = lambda message, category, *args, **kwargs: \
+                                '%s: %s' % (category.__name__, message)
+
 ROOT_PATH = os.path.dirname(os.path.abspath(__file__))
 BIN_DIR = os.path.abspath(os.path.join(ROOT_PATH, '..', 'bin'))
 
@@ -51,16 +55,26 @@ ADMIN_MEDIA_PREFIX = '/static/admin/'
 ROOT_URLCONF = 'openstack_dashboard.urls'
 
 HORIZON_CONFIG = {
-    'dashboards': ('nova', 'syspanel', 'settings',),
-    'default_dashboard': 'nova',
-    'user_home': 'horizon.views.base.get_user_home',
+    'dashboards': ('project', 'admin', 'settings',),
+    'default_dashboard': 'project',
+    'user_home': 'openstack_dashboard.views.get_user_home',
     'ajax_queue_limit': 10,
+    'auto_fade_alerts': {
+        'delay': 3000,
+        'fade_duration': 1500,
+        'types': ['alert-success', 'alert-info']
+    },
     'help_url': "http://docs.openstack.org",
     'exceptions': {'recoverable': exceptions.RECOVERABLE,
                    'not_found': exceptions.NOT_FOUND,
                    'unauthorized': exceptions.UNAUTHORIZED},
 }
 
+# Set to True to allow users to upload images to glance via Horizon server.
+# When enabled, a file form field will appear on the create image form.
+# See documentation for deployment considerations.
+HORIZON_IMAGES_ALLOW_UPLOAD = True
+
 MIDDLEWARE_CLASSES = (
     'django.middleware.common.CommonMiddleware',
     'django.middleware.csrf.CsrfViewMiddleware',
@@ -70,6 +84,7 @@ MIDDLEWARE_CLASSES = (
     'horizon.middleware.HorizonMiddleware',
     'django.middleware.doc.XViewMiddleware',
     'django.middleware.locale.LocaleMiddleware',
+    'django.middleware.clickjacking.XFrameOptionsMiddleware',
 )
 
 TEMPLATE_CONTEXT_PROCESSORS = (
@@ -80,6 +95,7 @@ TEMPLATE_CONTEXT_PROCESSORS = (
     'django.core.context_processors.static',
     'django.contrib.messages.context_processors.messages',
     'horizon.context_processors.horizon',
+    'openstack_dashboard.context_processors.openstack',
 )
 
 TEMPLATE_LOADERS = (
@@ -121,9 +137,9 @@ INSTALLED_APPS = (
     'django.contrib.humanize',
     'compressor',
     'horizon',
-    'horizon.dashboards.nova',
-    'horizon.dashboards.syspanel',
-    'horizon.dashboards.settings',
+    'openstack_dashboard.dashboards.project',
+    'openstack_dashboard.dashboards.admin',
+    'openstack_dashboard.dashboards.settings',
     'openstack_auth',
 )
 
@@ -167,5 +183,38 @@ try:
 except ImportError:
     logging.warning("No local_settings file found.")
 
+# Add HORIZON_CONFIG to the context information for offline compression
+COMPRESS_OFFLINE_CONTEXT = {
+    'STATIC_URL': STATIC_URL,
+    'HORIZON_CONFIG': HORIZON_CONFIG
+}
+
 if DEBUG:
     logging.basicConfig(level=logging.DEBUG)
+
+
+# Deprecation for Essex/Folsom dashboard names; remove this code in H.
+_renames = (
+    ('horizon.dashboards.nova', 'openstack_dashboard.dashboards.project'),
+    ('horizon.dashboards.syspanel', 'openstack_dashboard.dashboards.admin'),
+    ('horizon.dashboards.settings', 'openstack_dashboard.dashboards.settings')
+)
+
+INSTALLED_APPS = list(INSTALLED_APPS)
+_dashboards = list(HORIZON_CONFIG['dashboards'])
+
+for old, new in _renames:
+    if old in INSTALLED_APPS:
+        warnings.warn('The "%s" package is deprecated. Please update your '
+                      'INSTALLED_APPS setting to use the new "%s" package.\n'
+                      % (old, new), Warning)
+        INSTALLED_APPS[INSTALLED_APPS.index(old)] = new
+    _old_name = old.split(".")[-1]
+    if _old_name in HORIZON_CONFIG['dashboards'] and _old_name != "settings":
+        _new_name = new.split(".")[-1]
+        warnings.warn('The "%s" dashboard name is deprecated. Please update '
+                      'your HORIZON_CONFIG["dashboards"] setting to use the '
+                      'new "%s" dashboard name.\n' % (_old_name, _new_name),
+                      Warning)
+        _dashboards[_dashboards.index(_old_name)] = _new_name
+HORIZON_CONFIG['dashboards'] = _dashboards
